==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/Performance/src/com/clustercontrol/performance/composite/CollectionListComposite.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.composite;

import java.util.ArrayList;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.bean.StatusConstant;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.performance.action.RecordController;
import com.clustercontrol.performanceMGR.bean.CollectionTabelDefine;

/**
 * 収集情報一覧コンポジットクラス
 * 
 * @version 1.0
 * @since 1.0
 */
public class CollectionListComposite extends Composite {

    //	 ----- instance フィールド ----- //

    /** テーブルビューア */
    private CommonTableViewer tableViewer = null;

    // ----- コンストラクタ ----- //

    /**
     * インスタンスを返します。
     * 
     * @param parent 親のコンポジット
     * @param style スタイル
     */
    public CollectionListComposite(Composite parent, int style) {
        super(parent, style);
        initialize();
    }

    // ----- instance メソッド ----- //

    /**
     * 初期化を行います。
     */
    private void initialize() {
        GridLayout layout = new GridLayout(5, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.SINGLE);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        gridData.horizontalSpan = 5;
        table.setLayoutData(gridData);

        RecordController collector = RecordController.getInstance();
        // マネージャからオブジェクトを取得できた場合
        ArrayList list = collector.getCollectionListTableDefine();
        
        // テーブルビューアの作成
        this.tableViewer = new CommonTableViewer(table);
        this.tableViewer.createTableColumn(
        		list,
                CollectionTabelDefine.SORT_COLUMN_INDEX,
                CollectionTabelDefine.SORT_ORDER);
    }

    /**
     * 収集項目一覧を表示するテーブルを返します。
     * 
     * @return tableViewer 収集項目一覧を表示するテーブル
     */
    public CommonTableViewer getTableViewer() {
        return this.tableViewer;
    }

    /**
     * ビューを更新します。
     * 
     */
    public void update() {
        super.update();

        RecordController collector = RecordController.getInstance();

        if(collector != null){
        	tableViewer.setInput(collector.getCollectionList());
        }
    }
    
    /**
     * 現在選択されている収集IDを返します。
     *
     * @return 現在選択されている収集の収集ID
     */
    public String getSelectedID() {
    	Table table = tableViewer.getTable();
    	
    	int selectionIndex = table.getSelectionIndex();
    	
    	// 何も選択されていない場合はnullを返す
    	if(selectionIndex < 0){
    		return null;
    	}
    	
        return table.getItem(selectionIndex).getText(2);
    }
    
    /**
     * 現在選択されている収集の実行状態を返します。
     *
     * @return 現在選択されている収集の収集ID
     */
    public int getRunStatus() {
    	Table table = tableViewer.getTable();
    	String statusStr = table.getItem(table.getSelectionIndex()).getText(0);
        return StatusConstant.stringToType(statusStr);
    }
}

==> hinemos_src-3.0.3.tar.gz: Hinemos_src-3.0.3/Performance/src/com/clustercontrol/performance/composite/CollectionListComposite.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.composite;

import java.util.ArrayList;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;

import com.clustercontrol.bean.StatusConstant;
import com.clustercontrol.composite.CommonTableViewer;
import com.clustercontrol.performance.action.RecordController;
import com.clustercontrol.performance.bean.CollectionTabelDefine;

/**
 * 収集情報一覧コンポジットクラス
 * 
 * @version 1.0
 * @since 1.0
 */
public class CollectionListComposite extends Composite {

    //	 ----- instance フィールド ----- //

    /** テーブルビューア */
    private CommonTableViewer tableViewer = null;

    // ----- コンストラクタ ----- //

    /**
     * インスタンスを返します。
     * 
     * @param parent 親のコンポジット
     * @param style スタイル
     */
    public CollectionListComposite(Composite parent, int style) {
        super(parent, style);
        initialize();
    }

    // ----- instance メソッド ----- //

    /**
     * 初期化を行います。
     */
    private void initialize() {
        GridLayout layout = new GridLayout(5, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        Table table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
                | SWT.FULL_SELECTION | SWT.SINGLE);
        table.setHeaderVisible(true);
        table.setLinesVisible(true);

        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        gridData.horizontalSpan = 5;
        table.setLayoutData(gridData);

        RecordController collector = RecordController.getInstance();
        // マネージャからオブジェクトを取得できた場合
        ArrayList list = collector.getCollectionListTableDefine();
        
        // テーブルビューアの作成
        this.tableViewer = new CommonTableViewer(table);
        this.tableViewer.createTableColumn(
        		list,
                CollectionTabelDefine.SORT_COLUMN_INDEX,
                CollectionTabelDefine.SORT_ORDER);
    }

    /**
     * 収集項目一覧を表示するテーブルを返します。
     * 
     * @return tableViewer 収集項目一覧を表示するテーブル
     */
    public CommonTableViewer getTableViewer() {
        return this.tableViewer;
    }

    /**
     * ビューを更新します。
     * 
     */
    public void update() {
        super.update();

        RecordController collector = RecordController.getInstance();

        if(collector != null){
        	tableViewer.setInput(collector.getCollectionList());
        }
    }
    
    /**
     * 現在選択されている収集IDを返します。
     *
     * @return 現在選択されている収集の収集ID
     */
    public String getSelectedID() {
    	Table table = tableViewer.getTable();
    	
    	int selectionIndex = table.getSelectionIndex();
    	
    	// 何も選択されていない場合はnullを返す
    	if(selectionIndex < 0){
    		return null;
    	}
    	
        return table.getItem(selectionIndex).getText(2);
    }
    
    /**
     * 現在選択されている収集の実行状態を返します。
     *
     * @return 現在選択されている収集の収集ID
     */
    public int getRunStatus() {
    	Table table = tableViewer.getTable();
    	String statusStr = table.getItem(table.getSelectionIndex()).getText(0);
        return StatusConstant.stringToType(statusStr);
    }
}
